import { PlusOutlined } from '@ant-design/icons';
import { Modal, Button, message} from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import {
  GetDeviceInfoPage,
  GetDicList,
  AddDeviceInfo,
  UpdateDeviceInfo,
  DelDeviceInfo,
  GetDeviceType,
  GetDeviceVersions,
} from './services';
import { gettree } from '../../sys/org/service';
const key = 'message';

//添加
const handleAdd = async (fields) => {
  try {
    message.loading('正在添加', key);
    await AddDeviceInfo(JSON.stringify(fields)).then((r) => {
      message.destroy(key);
      if (r.data) {
        message.success('添加成功');
        return true;
      } else {
        message.error('添加失败');
        return false;
      }
    });
  } catch (error) {
    message.error('添加失败请重试！');
    return false;
  }
};
//修改
const handleUpdate = async (fields) => {
  try {
    message.loading('正在修改', key);
    await UpdateDeviceInfo(JSON.stringify(fields)).then((r) => {
      message.destroy(key);
      if (r.data) {
        message.success('修改成功');
        return true;
      } else {
        message.success('修改失败');
        return false;
      }
    });
  } catch (error) {
    message.error('修改失败请重试！');
    return false;
  }
};

//删除
const handleRemove = async (selectedRows) => {
  try {
    message.loading('正在删除');
    let ids = [];
    selectedRows.forEach((item) => {
      ids.push(item.id);
    });
    await DelDeviceInfo(ids).then((r) => {
      if (r.data) {
        message.success('删除成功');
        return true;
      } else {
        message.success('删除失败');
        return false;
      }
    });
  } catch (error) {
    message.error('删除失败请重试！');
    return false;
  }
};

const GoodsTypeManage = () => {
  const [storeType, setStoreType] = useState();

  const [storeTypeArray, setStoreTypeArray] = useState([]);
  const [OrgList, setOrgList] = useState([]);
  const [OrgListArray, setOrgListArray] = useState([]);
  const [dicDataAny, setDicDataAny] = useState([]);
  const [dicData, setDicData] = useState([]);

  const [deviceVersion, setDeviceVersion] = useState([]);
  //初始化数据
  useEffect(() => {
    const initStoreType = () => {
      GetDeviceType().then((data) => {
        let list = {};
        let list2 = [];
        data.data.forEach((item) => {
          list2.push({
            text: item.name,
            id: item.id,
          });
          list[item.id] = { text: item.name };
        });
        setStoreTypeArray(list2);
        setStoreType(list);
      });
    };
    function initOrgList() {
      gettree().then((r) => {
        inittree(r.data);
        function inittree(datas) {
          for (var i in datas) {
            if(  datas[i]['type']==2||  datas[i]['type']==3){
              datas[i]['disabled']=false;
            }else{
              datas[i]['disabled']=true;
            }
          
            if (datas[i].children) {
              inittree(datas[i].children);
            }
          }
        }
        setOrgList(r.data);
        let list = {};
        formateData(r.data);
        function formateData(datas) {
          for (var i in datas) {
            list[datas[i]['disabled']]=true;
            list[datas[i]['value']] = { text: datas[i]['title'] };
            if (datas[i].children) {
              formateData(datas[i].children);
            }
          }
        }
        setOrgListArray(list);
      });
    }
    initOrgList();
    initStoreType();
    function intDicData() {
      GetDicList('DeviceClientType').then((r) => {
        var arr = r.data;
        let data = {};
        if (r.succeeded) {
          var list = [];
          arr.forEach((item) => {
            data[item.code] = { text: item.code };
            list.push({
              code: item.code,
              value: item.code,
            });
          });
          setDicDataAny(data);
          setDicData(list);
        }
      });
    }
    intDicData();
    initDeviceVersion();
  }, []);

  const initDeviceVersion = async () => {
		const response = await GetDeviceVersions();
		if (response.statusCode == 200) {
			setDeviceVersion(response.data);
		} else {
			message.error('获取设备版本失败');
		}
	}

  /** 新建/更新窗口的弹窗 */
  const [createModalVisible, handleModalVisible] = useState(false);
  /** 分布更新窗口的弹窗 */
  const actionRef = useRef();
  const [currentRow, setCurrentRow] = useState();
  const [selectedRowsState, setSelectedRows] = useState([]);
  /** 国际化配置 */

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      hideInSearch: true,
      hideInTable: true,
      tip: '规则名称是唯一的 key',
    },
    {
      title: '设备名称',
      dataIndex: 'deviceName',
      valueType: 'textarea',
    },
    {
      title: '设备类型',
      dataIndex: 'deviceTypeKey',
      valueEnum: dicDataAny,
      hideInSearch: true,
    },
    {
      title: '归属门店',
      dataIndex: 'orgId',
      search: false,
      valueEnum: OrgListArray,
    },
    {
      title: '设备分类',
      dataIndex: 'deviceTypeId',
      valueEnum: storeType,
    },
    {
      title: '状态',
      dataIndex: 'status',
      valueEnum: {
        0: { text: '正常', status: 'Processing' },
        1: { text: '停用', status: 'Success' },
      },
      hideInSearch: true,
    },

    {
      title: '设备地址',
      dataIndex: 'deviceAddr',
      search: false,
      valueType: 'textarea',
    },
    {
      title: '坐标',
      dataIndex: 'deviceLoc',
      valueType: 'textarea',
      search: false,
    },

     {
      title: '设备唯一key',
      dataIndex: 'autoKey',
      search: false,
    },
    {
      title: '归属门店唯一key',
      dataIndex: 'orgKey',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="primary"
          onClick={() => {
            handleModalVisible(true);
            setCurrentRow(record);
          }}
        >
          {' '}
          更新
        </a>,
        <a
          key="primary2"
          onClick={() => {
            record.status = record.status == 0 ? 1 : 0;
            UpdateDeviceInfo(record).then((r) => {
              if (r.data) {
                actionRef.current.reload();
              }
            });
          }}
        >
          {' '}
          {record.store_Status == 0 ? '正常' :'停用'}
        </a>,

      ],
    },
  ];

  return (
    <PageContainer>
      <ProTable
        headerTitle="设备信息"
        actionRef={actionRef}
        rowKey="id"
        search={{
          labelWidth: 120,
        }}
        scroll={{ x: 2000 }}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              handleModalVisible(true);
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
        ]}
        request={async (params) => {
          var data = [];
          var total = 0;
          await GetDeviceInfoPage(params).then((r) => {
            data = r.data.data;
            total = r.data.total;
          });
          return {
            data: data,
            success: true,
            total: total,
          };
        }}
        columns={columns}
        rowSelection={{
          onChange: (_, selectedRows) => {
            setSelectedRows(selectedRows);
          },
        }}
      />
      {selectedRowsState?.length > 0 && (
        <FooterToolbar
          extra={
            <div>
              已选择{' '}
              <a
                style={{
                  fontWeight: 600,
                }}
              >
                {selectedRowsState.length}
              </a>{' '}
              项 &nbsp;&nbsp;
              {/* <span>
                服务调用次数总计 {selectedRowsState.reduce((pre, item) => pre + item.id, 0)} 万
              </span> */}
            </div>
          }
        >
          <Button
            onClick={async () => {
              await handleRemove(selectedRowsState);
              setSelectedRows([]);
              actionRef.current?.reloadAndRest?.();
            }}
          >
            删除
          </Button>
          {/* <Button type="primary">批量审批</Button> */}
        </FooterToolbar>
      )}

      <CreateForm
        storeType={storeTypeArray}
        OrgData={OrgList}
        dicData={dicData}
        onFinish={async (value) => {
          var success = false;
          if (value.id) {
            success = handleUpdate(value);
          } else {
            success = handleAdd(value);
          }
          if (success) {
            handleModalVisible(false);
            setCurrentRow(undefined);
            actionRef.current.reload();
          }
        }}
        onCancel={() => {
          handleModalVisible(false);
          setCurrentRow(undefined);
        }}
        createModalVisible={createModalVisible}
        deviceVersions={deviceVersion}
        values={currentRow || {}}
      />
    </PageContainer>
  );
};

export default GoodsTypeManage;
