import { DropboxOutlined, PlusOutlined, DownloadOutlined } from '@ant-design/icons';
import { Button, message, Select, Input, Drawer, Popconfirm } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import ProDescriptions from '@ant-design/pro-descriptions';
import ExportJsonExcel from 'js-export-excel';
import api from './service';
import OrderflowDetail from './orderflowDetail';

const handlerefund = async (value) => {
  var data = { number: value };
  const hide = message.loading('正在发起退款');
  try {
    api.StartRefund(data);
    hide();
    message.success('发起退款成功，即将刷新');
    return true;
  } catch (error) {
    hide();
    message.error('发起退款失败，请重试');
    return false;
  }
};
const Manage = () => {
  const [row, setRow] = useState();
  const [createModalVisible, handleModalVisible] = useState(false);
  //获取店铺分类(店铺类型)
  const [srdTypeList, setsrdTypeList] = useState([]);
  //获取店铺(店铺信息)
  const [srdList, setsrdList] = useState([]);
  const [dataList, setdataList] = useState([]);
  //绑定
  const actionRef = useRef();
  const [Selectparams, setparams] = useState([]);
  // 获取店铺分类、商品名称信息
  useEffect(() => {
    // //加盟商
    // function initfranchList() {
    //   api.franchList({ current: 1, pageSize: 20, status: '0' }).then((r) => {
    //     var arr2 = r.data.data;
    //     arr2.forEach((element) => {
    //       element.text = element.name;
    //       element.franchiseeId = element.id;
    //     });
    //     setfranchList(arr2);
    //   });
    // }
    //店铺分类（店铺类型）
    function initsrdTypeList() {
      api.srdTypeList().then((r) => {
        var arr = r.data;
        arr?.forEach((element) => {
          element.storeTypeId = element.id;
          element.text = element.name;
        });
        setsrdTypeList(arr);
      });
    }
    //店铺名称（店铺信息）
    function initsrdList() {
      api.srdList().then((r) => {
        var arr = r.data;
        arr?.forEach((element) => {
          element.value = element.id;
          element.label = element.name;
        });
        setsrdList(arr);
      });
    }
    //商品信息
    function initgoodsList() {
      api.goodsList().then((r) => {
        var arr1 = r.data;
        arr1.forEach((element) => {
          element.label = element.name;
          element.value = element.id;
        });
        console.log('获取下拉数据', arr1);
        setgoodList(arr1);
      });
    }

    //查询商品类型
    function initgoodsTypeList() {
      api.goodsTypeList().then((r) => {
        var arr2 = r.data;
        arr2.forEach((element) => {
          element.label = element.name;
          element.value = element.id;
        });
        setgoodsTypeList(arr2);
      });
    }
    //initfranchList();
    initsrdList();
    initsrdTypeList();
    // initgoodsList();
    // initgoodsTypeList();
  }, []);
  /**导出 */
  function handleExport() {
    api.GetFlowExport(Selectparams).then((res) => {
      let url = URL.createObjectURL(new Blob([res]));
      let filename = '订单流水.xlsx';
      let a = document.createElement('a');
      a.href = url;
      a.download = filename;
      a.click();
      URL.revokeObjectURL(url);
    });
  }
  /** 国际化配置 */

  const columns = [
    {
      title: '主键',
      dataIndex: 'id',
      tip: '规则名称是唯一的 key',
      hideInSearch: true,
      hideInTable: true,
    },
    {
      title: '订单时间',
      dataIndex: 'order_CreateTime',
      valueType: 'dateRange',
      hideInTable: true,
      search: {
        transform: (value) => {
          return {
            order_CreateTime: value[0],
            order_EndTime: value[1],
          };
        },
      },
    },
    {
      title: '手机号',
      dataIndex: 'Customer_Tel',
      hideInTable: true,
    },
    {
      title: '店铺分类',
      dataIndex: 'storeTypeId',
      hideInTable: true,
      valueType: 'select',
      valueEnum: srdTypeList,
    },
    {
      title: '店铺名称',
      dataIndex: 'storeId',
      hideInTable: true,
      valueType: 'select',
      renderFormItem: () => (
        <Select
          mode="multiple"
          showArrow
          optionFilterProp="label"
          placeholder="请选择店铺"
          style={{ width: '100%' }}
          options={srdList}
        />
      ),
    },
    {
      title: '订单状态',
      dataIndex: 'status',
      hideInTable: true,
      valueType: 'select',
      renderFormItem: () => (
        <Select mode="multiple" showArrow placeholder="订单状态" style={{ width: '100%' }}>
          <Option key={2}>支付成功</Option>
          <Option key={3}>等待制作</Option>
          <Option key={4}>制作中</Option>
          <Option key={5}>制作完成待取餐</Option>
          <Option key={6}>取餐完成</Option>
          <Option key={7}>受保护订单</Option>
          <Option key={8}>无主状态</Option>
          <Option key={9}>立即吃面</Option>
          <Option key={10}>无效订单</Option>
          <Option key={11}>废弃订单</Option>
          <Option key={20}>退款订单</Option>
          <Option key={21}>订单不可做</Option>
        </Select>
      ),
    },
    {
      title: '交易单号',
      dataIndex: 'order_Number',
      hideInSearch: true,
      // renderText: (dom, entity) => {
      //   return <a onClick={() =>
      //     setRow(entity),
      //     handleModalVisible(true)
      //   }>{dom}</a>;
      // },
    },
    {
      title: '店铺分类',
      dataIndex: 'storeTypeName',
      hideInSearch: true,
    },

    {
      title: '店铺名称',
      dataIndex: 'storeName',
      hideInSearch: true,
    },

    {
      title: '应付金额',
      dataIndex: 'order_OriginalMoney',
      renderText: (val) => `${val}¥`,
      hideInSearch: true,
    },
    {
      title: '实付金额',
      dataIndex: 'order_RealMoney',
      hideInSearch: true,
      renderText: (val) => `${val}¥`,
    },
    {
      title: '应付金额(退)',
      dataIndex: 'refundOriginalMoney',
      renderText: (val) => `${val}¥`,
      hideInSearch: true,
    },
    {
      title: '实付金额(退)',
      dataIndex: 'refundRealMoney',
      hideInSearch: true,
      renderText: (val) => `${val}¥`,
    },
    {
      title: '数量',
      dataIndex: 'order_Count',
      hideInSearch: true,
    },
    {
      title: '创建时间',
      sorter: true,
      dataIndex: 'order_CreateTime',
      valueType: 'dateTime',
      hideInSearch: true,
      renderFormItem: (item, { defaultRender, ...rest }, form) => {
        const status = form.getFieldValue('status');

        if (`${status}` === '0') {
          return false;
        }

        if (`${status}` === '3') {
          return <Input {...rest} placeholder="请输入异常原因！" />;
        }

        return defaultRender(item);
      },
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      render: (_, record) => [
        <a
          key="config"
          onClick={() => {
            setRow(record), handleModalVisible(true);
          }}
        >
          查看详情
        </a>,
        <a
          key="config"
          onClick={() => {
            api.printsmallticket({ "orderId": record.id })
              .then(re => {
                if (re.data) {
                  message.success('打印成功');
                } else {
                  message.error('打印失败');
                }

              })

          }} >
          打印小票
        </a>,
      ],
    },
  ];

  return (
    <PageContainer>
      <ProTable
        headerTitle="订单流水"
        actionRef={actionRef}
        rowKey="id"
        search={{
          labelWidth: 120,
        }}
        toolBarRender={() => [
          <Button type="primary" key="create" onClick={() => handleExport()}>
            <DownloadOutlined /> 导出
          </Button>,
        ]}
        columns={columns}
        //数据绑定
        request={async (params, sorter, filter) => {
          if (params.storeTypeId != undefined) {
            //店铺分类
            params.storeTypeId = srdTypeList[params.storeTypeId].storeTypeId;
          }
          const msg = await api.orderList(params);
          setparams(params);
          setdataList(msg.data.data);
          return {
            data: msg.data.data,
            success: true,
            total: msg.data.total,
          };
        }}
      ></ProTable>

      {!!row && (
        <OrderflowDetail
          // onFinish={async (value) => {
          //   var success = false;

          // }}
          onCancel={() => {
            setRow(undefined);
            handleModalVisible(false);
          }}
          createModalVisible={createModalVisible}
          values={row || {}}
        />
      )}
    </PageContainer>
  );
};

export default Manage;
